@@ -1023,7 +1023,7 @@ cheese_window_cmd_about (GtkAction *action, CheeseWindow *cheese_window)
 
   gtk_show_about_dialog (GTK_WINDOW (cheese_window->window),
                          "version", VERSION,
-                         "copyright", "Copyright \xc2\xa9 2007, 2008\n daniel g. siegel <dgsiegel@gmail.com>",
+                         "copyright", "Copyright \xc2\xa9 2007 - 2009\n daniel g. siegel <dgsiegel@gnome.org>",
                          "comments", _("Take photos and videos with your webcam, with fun graphical effects"),
                          "authors", authors,
                          "translator-credits", translators,
@@ -1818,16 +1818,16 @@ cheese_window_create_window (CheeseWindow *cheese_window)
   gtk_action_group_set_sensitive (cheese_window->actions_file, FALSE);
 
   action = gtk_ui_manager_get_action (cheese_window->ui_manager, "/MainMenu/Edit/Effects");
-  gtk_action_connect_proxy (GTK_ACTION (action), GTK_WIDGET (cheese_window->button_effects));
-  gtk_action_connect_proxy (GTK_ACTION (action), GTK_WIDGET (cheese_window->button_effects_fullscreen));
+  gtk_activatable_set_related_action (GTK_ACTIVATABLE (cheese_window->button_effects), action);
+  gtk_activatable_set_related_action (GTK_ACTIVATABLE (cheese_window->button_effects_fullscreen), action);
 
   action = gtk_ui_manager_get_action (cheese_window->ui_manager, "/MainMenu/Cheese/Photo");
-  gtk_action_connect_proxy (GTK_ACTION (action), GTK_WIDGET (cheese_window->button_photo));
-  gtk_action_connect_proxy (GTK_ACTION (action), GTK_WIDGET (cheese_window->button_photo_fullscreen));
+  gtk_activatable_set_related_action (GTK_ACTIVATABLE (cheese_window->button_photo), action);
+  gtk_activatable_set_related_action (GTK_ACTIVATABLE (cheese_window->button_photo_fullscreen), action);
 
   action = gtk_ui_manager_get_action (cheese_window->ui_manager, "/MainMenu/Cheese/Video");
-  gtk_action_connect_proxy (GTK_ACTION (action), GTK_WIDGET (cheese_window->button_video));
-  gtk_action_connect_proxy (GTK_ACTION (action), GTK_WIDGET (cheese_window->button_video_fullscreen));
+  gtk_activatable_set_related_action (GTK_ACTIVATABLE (cheese_window->button_video), action);
+  gtk_activatable_set_related_action (GTK_ACTIVATABLE (cheese_window->button_video_fullscreen), action);
 
 
   /* Default handlers for closing the application */
@@ -1852,12 +1852,23 @@ setup_camera (CheeseWindow *cheese_window)
   char      *webcam_device = NULL;
   int        x_resolution;
   int        y_resolution;
+  gdouble    brightness;
+  gdouble    contrast;
+  gdouble    saturation;
+  gdouble    hue;
   GtkWidget *message_area;
 
   GError *error;
 
-  g_object_get (cheese_window->gconf, "gconf_prop_x_resolution", &x_resolution,
-                "gconf_prop_y_resolution", &y_resolution, "gconf_prop_webcam", &webcam_device, NULL);
+  g_object_get (cheese_window->gconf,
+                "gconf_prop_x_resolution", &x_resolution,
+                "gconf_prop_y_resolution", &y_resolution,
+                "gconf_prop_webcam", &webcam_device,
+                "gconf_prop_brightness", &brightness,
+                "gconf_prop_contrast", &contrast,
+                "gconf_prop_saturation", &saturation,
+                "gconf_prop_hue", &hue,
+                NULL);
 
   gdk_threads_enter ();
   cheese_window->webcam = cheese_webcam_new (cheese_window->screen,
@@ -1908,6 +1919,11 @@ setup_camera (CheeseWindow *cheese_window)
   cheese_webcam_set_effect (cheese_window->webcam,
                             cheese_effect_chooser_get_selection (CHEESE_EFFECT_CHOOSER (cheese_window->effect_chooser)));
 
+  cheese_webcam_set_balance_property (cheese_window->webcam, "brightness", brightness);
+  cheese_webcam_set_balance_property (cheese_window->webcam, "contrast", contrast);
+  cheese_webcam_set_balance_property (cheese_window->webcam, "saturation", saturation);
+  cheese_webcam_set_balance_property (cheese_window->webcam, "hue", hue);
+
   cheese_webcam_play (cheese_window->webcam);
   gdk_threads_enter ();
   gtk_notebook_set_current_page (GTK_NOTEBOOK (cheese_window->notebook), 0);
